SqrtFoot

Type Alias SqrtFoot 

pub type SqrtFoot<V> = FPS<V, SqrtFoot>;

Aliased Type

pub struct SqrtFoot<V> {
    pub value_unsafe: V,
    /* private fields */
}

Fields

value_unsafe: V

This is the value of whatever type we’re giving units. Using it directly bypasses all of the dimensional analysis that having a unit system provides, and should be avoided whenever possible.

If using this member is necessary, it is strongly encouraged to wrap the calculation in a dimensionally-safe interface.